==> change_author_action-8.x-1.0.tar.gz: change_author_action/src/Form/ChangeAuthorActionForm.php <==
<?php

namespace Drupal\change_author_action\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Session\SessionManagerInterface;
use Drupal\user\Entity\User;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Routing\RouteBuilderInterface;
use Drupal\Core\TempStore\PrivateTempStoreFactory;

/**
 * ChangeAuthorActionForm.
 */
class ChangeAuthorActionForm extends FormBase implements FormInterface {

  /**
   * Set a var to make stepthrough form.
   */
  protected $step = 1;
  /**
   * Keep track of user input.
   */
  protected $userInput = [];

  /**
   * Tempstorage.
   */
  protected $tempStoreFactory;

  /**
   * Session.
   */
  private $sessionManager;

  /**
   * User.
   */
  private $currentUser;

  /**
   * The route builder.
   */
  protected $routeBuilder;

  /**
   * Constructs a \Drupal\change_author_action\Form\BulkUpdateFieldsForm.
   *
   * @param \Drupal\Core\TempStore\PrivateTempStoreFactory $temp_store_factory
   *   Temp storage.
   * @param \Drupal\Core\Session\SessionManagerInterface $session_manager
   *   Session.
   * @param \Drupal\Core\Session\AccountInterface $current_user
   *   User.
   * @param \Drupal\Core\Routing\RouteBuilderInterface $route_builder
   *   Route.
   */
  public function __construct(PrivateTempStoreFactory $temp_store_factory, SessionManagerInterface $session_manager, AccountInterface $current_user, RouteBuilderInterface $route_builder) {
    $this->tempStoreFactory = $temp_store_factory;
    $this->sessionManager = $session_manager;
    $this->currentUser = $current_user;
    $this->routeBuilder = $route_builder;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('tempstore.private'),
      $container->get('session_manager'),
      $container->get('current_user'),
      $container->get('router.builder')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'change_author_action_form';
  }

  /**
   * {@inheritdoc}
   */
  public function updateFields() {
    $entities = $this->userInput['entities'];
    $new_author = $this->userInput['new_author'];

    $a = 1;
    $batch = [
      'title' => $this->t('Changing author...'),
      'operations' => [
        [
          '\Drupal\change_author_action\ChangeAuthorAction::updateFields',
          [$entities, $new_author],
        ],
      ],
      'finished' => '\Drupal\change_author_action\ChangeAuthorAction::changeAuthorActionFinishedCallback',
    ];
    batch_set($batch);
    return 'Author successfully changed';
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    switch ($this->step) {
      case 1:
        $form_state->setRebuild();
        break;

      case 2:
        if (method_exists($this, 'updateFields')) {
          $return_verify = $this->updateFields();
        }
        \Drupal::messenger()->addStatus($return_verify);
        $this->routeBuilder->rebuild();
        break;
    }
    $this->step++;
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    if (isset($this->form)) {
      $form = $this->form;
    }
    $form['#title'] = $this->t('Choose new author for selected items');
    $submit_label = 'Next';

    switch ($this->step) {
      case 1:
        // Retrieve IDs from the temporary storage.
        $this->userInput['entities'] = $this->tempStoreFactory
          ->get('change_author_ids')
          ->get($this->currentUser->id());
        $form['new_author'] = [
          '#title' => ('Choose new author'),
          '#type' => 'entity_autocomplete',
          '#target_type' => 'user',
          '#required' => TRUE,
          '#selection_settings' => [
            'include_anonymous' => FALSE,
          ],
        ];
        break;

      case 2:
        $uid = $form_state->getValue('new_author');
        $this->userInput['new_author'] = $uid;
        $user = User::load($uid);
        $form['#title'] .= ' - ' . $this->t('Are you sure you want to alter the author to @author_name on @count_entities entities?',
            [
              '@author_name' => $user->label(),
              '@count_entities' => count($this->userInput['entities']),
            ]
        );
        $submit_label = $this->t('Change author on selected entities');

        break;
    }
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $submit_label,
      '#button_type' => 'primary',
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    // TODO.
  }

}

==> change_author_action-8.x-1.1.tar.gz: change_author_action/src/Form/ChangeAuthorActionForm.php <==
<?php

namespace Drupal\change_author_action\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Session\SessionManagerInterface;
use Drupal\user\Entity\User;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Routing\RouteBuilderInterface;
use Drupal\Core\TempStore\PrivateTempStoreFactory;
use Drupal\Core\Messenger\MessengerInterface;

/**
 * ChangeAuthorActionForm.
 */
class ChangeAuthorActionForm extends FormBase implements FormInterface {

  /**
   * Set a var to make stepthrough form.
   */
  protected $step = 1;
  /**
   * Keep track of user input.
   */
  protected $userInput = [];

  /**
   * Tempstorage.
   */
  protected $tempStoreFactory;

  /**
   * Session.
   */
  private $sessionManager;

  /**
   * User.
   */
  private $currentUser;

  /**
   * The route builder.
   */
  protected $routeBuilder;

  /**
   * The messenger.
   */
  protected $messenger;

  /**
   * Constructs a \Drupal\change_author_action\Form\BulkUpdateFieldsForm.
   *
   * @param \Drupal\Core\TempStore\PrivateTempStoreFactory $temp_store_factory
   *   Temp storage.
   * @param \Drupal\Core\Session\SessionManagerInterface $session_manager
   *   Session.
   * @param \Drupal\Core\Session\AccountInterface $current_user
   *   User.
   * @param \Drupal\Core\Routing\RouteBuilderInterface $route_builder
   *   Route.
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   Messenger.
   */
  public function __construct(PrivateTempStoreFactory $temp_store_factory, SessionManagerInterface $session_manager, AccountInterface $current_user, RouteBuilderInterface $route_builder, MessengerInterface $messenger) {
    $this->tempStoreFactory = $temp_store_factory;
    $this->sessionManager = $session_manager;
    $this->currentUser = $current_user;
    $this->routeBuilder = $route_builder;
    $this->messenger = $messenger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('tempstore.private'),
      $container->get('session_manager'),
      $container->get('current_user'),
      $container->get('router.builder'),
      $container->get('messenger')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'change_author_action_form';
  }

  /**
   * {@inheritdoc}
   */
  public function updateFields() {
    $entities = $this->userInput['entities'];
    $new_author = $this->userInput['new_author'];

    $a = 1;
    $batch = [
      'title' => $this->t('Changing author...'),
      'operations' => [
        [
          '\Drupal\change_author_action\ChangeAuthorAction::updateFields',
          [$entities, $new_author],
        ],
      ],
      'finished' => '\Drupal\change_author_action\ChangeAuthorAction::changeAuthorActionFinishedCallback',
    ];
    batch_set($batch);
    return $this->t('Author successfully changed.');
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    switch ($this->step) {
      case 1:
        $form_state->setRebuild();
        break;

      case 2:
        if (method_exists($this, 'updateFields')) {
          $return_verify = $this->updateFields();
        }
        $this->messenger->addStatus($return_verify);
        $this->routeBuilder->rebuild();
        break;
    }
    $this->step++;
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    if (isset($this->form)) {
      $form = $this->form;
    }
    $form['#title'] = $this->t('Choose new author for selected items');
    $submit_label = $this->t('Next');

    switch ($this->step) {
      case 1:
        // Retrieve IDs from the temporary storage.
        $this->userInput['entities'] = $this->tempStoreFactory
          ->get('change_author_ids')
          ->get($this->currentUser->id());
        $form['new_author'] = [
          '#title' => $this->t('Choose new author'),
          '#type' => 'entity_autocomplete',
          '#target_type' => 'user',
          '#required' => TRUE,
          '#selection_settings' => [
            'include_anonymous' => FALSE,
          ],
        ];
        break;

      case 2:
        $uid = $form_state->getValue('new_author');
        $this->userInput['new_author'] = $uid;
        $user = User::load($uid);
        $form['#title'] .= ' - ' . $this->formatPlural(
            count($this->userInput['entities']),
            'Are you sure you want to alter the author to @author_name on one entity?',
            'Are you sure you want to alter the author to @author_name on @count entities?',
            [
              '@author_name' => $user->label(),
            ]
        );
        $submit_label = $this->t('Change author on selected entities');

        break;
    }
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $submit_label,
      '#button_type' => 'primary',
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    // TODO.
  }

}
